# Slot: prefix uri


A URI associated with a given prefix

URI: [http://w3id.org/biolink/biolinkml/meta/prefix_uri](slot_uri)
## Domain and Range

[Prefix](Prefix.md) -> [Uri](Uri.md)
## Inheritance

## Children

## Used by

 * [Prefix](Prefix.md)
